@@ -1,4 +1,5 @@
 """Python wrapper for NextDNS API."""
+
 from __future__ import annotations
 
 import asyncio
@@ -7,12 +8,20 @@ from collections.abc import Iterable
 from http import HTTPStatus
 from typing import Any, cast
 
-from aiohttp import ClientSession
+from aiohttp import ClientConnectorError, ClientSession
+from tenacity import (
+    after_log,
+    retry,
+    retry_if_exception_type,
+    stop_after_attempt,
+    wait_incrementing,
+)
 
 from .const import (
     ALLOWED_LOGS_LOCATION,
     ALLOWED_LOGS_RETENTION,
     ATTR_ANALYTICS,
+    ATTR_BAV,
     ATTR_CLEAR_LOGS,
     ATTR_ENABLED,
     ATTR_GET_LOGS,
@@ -29,6 +38,7 @@ from .const import (
     ATTR_TEST,
     ATTR_WEB3,
     ENDPOINTS,
+    HTTP_STATUS_TIMEOUT,
     MAP_DNSSEC,
     MAP_ENCRYPTED,
     MAP_IP_VERSIONS,
@@ -38,6 +48,10 @@ from .const import (
     MAP_STATUS,
     PARENTAL_CONTROL_CATEGORIES,
     PARENTAL_CONTROL_SERVICES,
+    STOP_AFTER_ATTEMPT,
+    TIMEOUT,
+    WAIT_INCREMENT,
+    WAIT_START,
 )
 from .exceptions import (
     ApiError,
@@ -88,12 +102,24 @@ class NextDns:
         _LOGGER.debug("Initializing with API Key: %s...", self._api_key[:10])
         self._profiles = list(self._parse_profiles(await self.get_profiles()))
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_profiles(self) -> list[dict[str, str]]:
         """Get all profiles."""
         url = ENDPOINTS[ATTR_PROFILES]
 
         return cast(list[dict[str, str]], await self._http_request("get", url))
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_profile(self, profile_id: str) -> Profile:
         """Get profile."""
         url = ENDPOINTS[ATTR_PROFILE].format(profile_id=profile_id)
@@ -118,6 +144,7 @@ class NextDns:
         }
 
         return Settings(
+            bav=profile_data.settings[ATTR_BAV],
             block_page=profile_data.settings["blockPage"][ATTR_ENABLED],
             cache_boost=profile_data.settings[ATTR_PERFORMANCE][ApiNames.CACHE_BOOST],
             cname_flattening=profile_data.settings[ATTR_PERFORMANCE][
@@ -153,19 +180,24 @@ class NextDns:
             ],
             block_9gag=services.get(ParentalControlServices.NINEGAG, False),
             block_amazon=services.get(ParentalControlServices.AMAZON, False),
+            block_bereal=services.get(ParentalControlServices.BEREAL, False),
             block_blizzard=services.get(ParentalControlServices.BLIZZARD, False),
+            block_chatgpt=services.get(ParentalControlServices.CHATGPT, False),
             block_dailymotion=services.get(ParentalControlServices.DAILYMOTION, False),
             block_discord=services.get(ParentalControlServices.DISCORD, False),
             block_disneyplus=services.get(ParentalControlServices.DISNEYPLUS, False),
             block_ebay=services.get(ParentalControlServices.EBAY, False),
             block_facebook=services.get(ParentalControlServices.FACEBOOK, False),
             block_fortnite=services.get(ParentalControlServices.FORTNITE, False),
+            block_google_chat=services.get(ParentalControlServices.GOOGLE_CHAT, False),
+            block_hbomax=services.get(ParentalControlServices.HBOMAX, False),
             block_hulu=services.get(ParentalControlServices.HULU, False),
             block_imgur=services.get(ParentalControlServices.IMGUR, False),
             block_instagram=services.get(ParentalControlServices.INSTAGRAM, False),
             block_leagueoflegends=services.get(
                 ParentalControlServices.LEAGUEOFLEGENDS, False
             ),
+            block_mastodon=services.get(ParentalControlServices.MASTODON, False),
             block_messenger=services.get(ParentalControlServices.MESSENGER, False),
             block_minecraft=services.get(ParentalControlServices.MINECRAFT, False),
             block_netflix=services.get(ParentalControlServices.NETFLIX, False),
@@ -193,12 +225,27 @@ class NextDns:
             block_dating=categories.get(ParentalControlCategories.DATING, False),
             block_gambling=categories.get(ParentalControlCategories.GAMBLING, False),
             block_piracy=categories.get(ParentalControlCategories.PIRACY, False),
+            block_playstation_network=services.get(
+                ParentalControlServices.PLAYSTATION_NETWORK, False
+            ),
             block_porn=categories.get(ParentalControlCategories.PORN, False),
             block_social_networks=categories.get(
                 ParentalControlCategories.SOCIAL_NETWORKS, False
             ),
+            block_online_gaming=categories.get(
+                ParentalControlCategories.ONLINE_GAMING, False
+            ),
+            block_video_streaming=categories.get(
+                ParentalControlCategories.VIDEO_STREAMING, False
+            ),
         )
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_analytics_status(self, profile_id: str) -> AnalyticsStatus:
         """Get profile analytics status."""
         url = ENDPOINTS[ATTR_ANALYTICS].format(profile_id=profile_id, type="status")
@@ -208,6 +255,12 @@ class NextDns:
             **{MAP_STATUS[item["status"]]: item["queries"] for item in resp}
         )
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_analytics_dnssec(self, profile_id: str) -> AnalyticsDnssec:
         """Get profile analytics dnssec."""
         url = ENDPOINTS[ATTR_ANALYTICS].format(profile_id=profile_id, type="dnssec")
@@ -217,6 +270,12 @@ class NextDns:
             **{MAP_DNSSEC[item["validated"]]: item["queries"] for item in resp}
         )
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_analytics_encryption(self, profile_id: str) -> AnalyticsEncryption:
         """Get profile analytics encryption."""
         url = ENDPOINTS[ATTR_ANALYTICS].format(profile_id=profile_id, type="encryption")
@@ -226,6 +285,12 @@ class NextDns:
             **{MAP_ENCRYPTED[item["encrypted"]]: item["queries"] for item in resp}
         )
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_analytics_ip_versions(self, profile_id: str) -> AnalyticsIpVersions:
         """Get profile analytics IP versions."""
         url = ENDPOINTS[ATTR_ANALYTICS].format(profile_id=profile_id, type="ipVersions")
@@ -235,6 +300,12 @@ class NextDns:
             **{MAP_IP_VERSIONS[item["version"]]: item["queries"] for item in resp}
         )
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_analytics_protocols(self, profile_id: str) -> AnalyticsProtocols:
         """Get profile analytics protocols."""
         url = ENDPOINTS[ATTR_ANALYTICS].format(profile_id=profile_id, type="protocols")
@@ -244,6 +315,12 @@ class NextDns:
             **{MAP_PROTOCOLS[item["protocol"]]: item["queries"] for item in resp}
         )
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def connection_status(self, profile_id: str) -> ConnectionStatus:
         """Return True if the device is using NextDNS."""
         url = ENDPOINTS[ATTR_TEST].format(profile_id=profile_id)
@@ -264,6 +341,12 @@ class NextDns:
 
         return result.get("success", False) is True
 
+    @retry(
+        retry=retry_if_exception_type((TimeoutError, ClientConnectorError)),
+        stop=stop_after_attempt(STOP_AFTER_ATTEMPT),
+        wait=wait_incrementing(start=WAIT_START, increment=WAIT_INCREMENT),
+        after=after_log(_LOGGER, logging.DEBUG),
+    )
     async def get_logs(self, profile_id: str) -> str:
         """Get NextDNS logs."""
         url = ENDPOINTS[ATTR_GET_LOGS].format(profile_id=profile_id)
@@ -366,11 +449,12 @@ class NextDns:
                 url,
                 headers=self._headers,
                 json=data,
+                timeout=TIMEOUT,
             )
         else:
             resp = await self._session.request(method, url, headers=self._headers)
 
-        _LOGGER.debug("Response status: %s", resp.status)
+        _LOGGER.debug("Response status %s for %s", resp.status, url)
 
         if resp.status == HTTPStatus.FORBIDDEN.value:
             raise InvalidApiKeyError
@@ -380,10 +464,19 @@ class NextDns:
             "post",
         ):
             return {"success": True}
+        if resp.status == HTTPStatus.TOO_MANY_REQUESTS.value:
+            raise ApiError("Too many requests")
+        if resp.status == HTTP_STATUS_TIMEOUT:
+            raise TimeoutError("Timeout occurred: HTTP 524")
         if resp.status != HTTPStatus.OK.value:
-            result = await resp.json()
-            error = result["errors"][0]
-            raise ApiError(f"{resp.status}, {error['code']}, {error.get('detail')}")
+            if resp.content_type == "application/json":
+                result = await resp.json()
+                error = result["errors"][0]
+                raise ApiError(
+                    f"{resp.status}, {error['code']}, "
+                    f"{error.get('detail', 'no detail')}"
+                )
+            raise ApiError(f"Error code: {resp.status}")
 
         if resp.content_type == "application/json":
             result = await resp.json()
