@@ -1,4 +1,7 @@
 """NextDNS constants."""
+
+from aiohttp import ClientTimeout
+
 from .model import (
     ApiNames,
     ParentalControlCategories,
@@ -29,6 +32,7 @@ ATTR_SETTINGS = "settings"
 ATTR_TEST = "test"
 
 ATTR_ANONYMIZED_ECS = "anonymized_ecs"
+ATTR_BAV = "bav"
 ATTR_BLOCK_PAGE = "block_page"
 ATTR_CACHE_BOOST = "cache_boost"
 ATTR_CNAME_FLATTENING = "cname_flattening"
@@ -112,6 +116,7 @@ MAP_SETTING = {
         ENDPOINTS[ATTR_PERFORMANCE], ApiNames.CNAME_FLATTENING
     ),
     ATTR_ANONYMIZED_ECS: SettingDescription(ENDPOINTS[ATTR_PERFORMANCE], ApiNames.ECS),
+    ATTR_BAV: SettingDescription(ENDPOINTS[ATTR_SETTINGS], ATTR_BAV),
     ATTR_WEB3: SettingDescription(ENDPOINTS[ATTR_SETTINGS], ATTR_WEB3),
     ATTR_LOGS: SettingDescription(ENDPOINTS[ATTR_LOGS], ATTR_ENABLED),
     ATTR_LOGS_LOCATION: SettingDescription(ENDPOINTS[ATTR_LOGS], ATTR_LOCATION),
@@ -272,6 +277,25 @@ MAP_SETTING = {
     ParentalControlServicesAttrs.BLOCK_SIGNAL: SettingDescription(
         ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.SIGNAL
     ),
+    ParentalControlServicesAttrs.BLOCK_BEREAL: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.BEREAL
+    ),
+    ParentalControlServicesAttrs.BLOCK_GOOGLE_CHAT: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.GOOGLE_CHAT
+    ),
+    ParentalControlServicesAttrs.BLOCK_CHATGPT: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.CHATGPT
+    ),
+    ParentalControlServicesAttrs.BLOCK_HBOMAX: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.HBOMAX
+    ),
+    ParentalControlServicesAttrs.BLOCK_MASTODON: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.MASTODON
+    ),
+    ParentalControlServicesAttrs.BLOCK_PLAYSTATION_NETWORK: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE],
+        ParentalControlServices.PLAYSTATION_NETWORK,
+    ),
     ParentalControlCategoriesAttrs.BLOCK_DATING: SettingDescription(
         ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY], ParentalControlCategories.DATING
     ),
@@ -288,7 +312,22 @@ MAP_SETTING = {
         ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY],
         ParentalControlCategories.SOCIAL_NETWORKS,
     ),
+    ParentalControlCategoriesAttrs.BLOCK_VIDEO_STREAMING: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY],
+        ParentalControlCategories.VIDEO_STREAMING,
+    ),
+    ParentalControlCategoriesAttrs.BLOCK_ONLINE_GAMING: SettingDescription(
+        ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY],
+        ParentalControlCategories.ONLINE_GAMING,
+    ),
 }
 
 ALLOWED_LOGS_LOCATION = ("ch", "eu", "gb", "us")
 ALLOWED_LOGS_RETENTION = (1, 6, 24, 168, 720, 2160, 4320, 8760, 17520)
+
+TIMEOUT = ClientTimeout(total=5)
+STOP_AFTER_ATTEMPT = 3
+WAIT_INCREMENT = 2
+WAIT_START = 2
+
+HTTP_STATUS_TIMEOUT = 524
