@@ -1,34 +1,10 @@
 """Type definitions for NextDNS."""
+
 from __future__ import annotations
 
 from dataclasses import dataclass
-from enum import Enum
-from typing import Any, TypeVar
-
-_StrEnumSelfT = TypeVar("_StrEnumSelfT", bound="StrEnum")
-
-
-class StrEnum(str, Enum):
-    """Partial backport of Python 3.11's StrEnum for our basic use cases."""
-
-    def __new__(
-        cls: type[_StrEnumSelfT], value: str, *args: Any, **kwargs: Any
-    ) -> _StrEnumSelfT:
-        """Create a new StrEnum instance."""
-        if not isinstance(value, str):
-            raise TypeError(f"{value!r} is not a string")
-        return super().__new__(cls, value, *args, **kwargs)
-
-    def __str__(self) -> str:
-        """Return self.value."""
-        return str(self.value)
-
-    @staticmethod
-    def _generate_next_value_(
-        name: str, start: int, count: int, last_values: list[Any]
-    ) -> Any:
-        """Make `auto()` explicitly unsupported."""
-        raise TypeError("auto() is not supported by this implementation")
+from enum import StrEnum
+from typing import Any
 
 
 @dataclass
@@ -188,7 +164,7 @@ class Profile(NextDnsData):
     allowlist: list[dict[str, Any]]
     denylist: list[dict[str, Any]]
     fingerprint: str
-    id: str  # noqa: A003
+    id: str
     name: str
     parental_control: dict[str, Any]
     privacy: dict[str, Any]
@@ -202,6 +178,7 @@ class Profile(NextDnsData):
 class Settings(NextDnsData):
     """Settings class."""
 
+    bav: bool
     block_page: bool
     cache_boost: bool
     cname_flattening: bool
@@ -233,21 +210,27 @@ class Settings(NextDnsData):
 
     block_9gag: bool
     block_amazon: bool
+    block_bereal: bool
     block_blizzard: bool
+    block_chatgpt: bool
     block_dailymotion: bool
     block_discord: bool
     block_disneyplus: bool
     block_ebay: bool
     block_facebook: bool
     block_fortnite: bool
+    block_google_chat: bool
+    block_hbomax: bool
     block_hulu: bool
     block_imgur: bool
     block_instagram: bool
     block_leagueoflegends: bool
+    block_mastodon: bool
     block_messenger: bool
     block_minecraft: bool
     block_netflix: bool
     block_pinterest: bool
+    block_playstation_network: bool
     block_primevideo: bool
     block_reddit: bool
     block_roblox: bool
@@ -274,13 +257,15 @@ class Settings(NextDnsData):
     block_piracy: bool
     block_porn: bool
     block_social_networks: bool
+    block_online_gaming: bool
+    block_video_streaming: bool
 
 
 @dataclass
 class ProfileInfo(NextDnsData):
     """ProfileInfo class."""
 
-    id: str  # noqa: A003
+    id: str
     fingerprint: str
     name: str
 
@@ -297,22 +282,28 @@ class ParentalControlServices(StrEnum):
     """Service type for parental control."""
 
     AMAZON = "amazon"
+    BEREAL = "bereal"
     BLIZZARD = "blizzard"
+    CHATGPT = "chatgpt"
     DAILYMOTION = "dailymotion"
     DISCORD = "discord"
     DISNEYPLUS = "disneyplus"
     EBAY = "ebay"
     FACEBOOK = "facebook"
     FORTNITE = "fortnite"
+    GOOGLE_CHAT = "google-chat"
+    HBOMAX = "hbomax"
     HULU = "hulu"
     IMGUR = "imgur"
     INSTAGRAM = "instagram"
     LEAGUEOFLEGENDS = "leagueoflegends"
+    MASTODON = "mastodon"
     MESSENGER = "messenger"
     MINECRAFT = "minecraft"
     NETFLIX = "netflix"
     NINEGAG = "9gag"
     PINTEREST = "pinterest"
+    PLAYSTATION_NETWORK = "playstation-network"
     PRIMEVIDEO = "primevideo"
     REDDIT = "reddit"
     ROBLOX = "roblox"
@@ -340,21 +331,27 @@ class ParentalControlServicesAttrs(StrEnum):
 
     BLOCK_9GAG = "block_9gag"
     BLOCK_AMAZON = "block_amazon"
+    BLOCK_BEREAL = "block_bereal"
     BLOCK_BLIZZARD = "block_blizzard"
+    BLOCK_CHATGPT = "block_chatgpt"
     BLOCK_DAILYMOTION = "block_dailymotion"
     BLOCK_DISCORD = "block_discord"
     BLOCK_DISNEYPLUS = "block_disneyplus"
     BLOCK_EBAY = "block_ebay"
     BLOCK_FACEBOOK = "block_facebook"
     BLOCK_FORTNITE = "block_fortnite"
+    BLOCK_GOOGLE_CHAT = "block_google_chat"
+    BLOCK_HBOMAX = "block_hbomax"
     BLOCK_HULU = "block_hulu"
     BLOCK_IMGUR = "block_imgur"
     BLOCK_INSTAGRAM = "block_instagram"
     BLOCK_LEAGUEOFLEGENDS = "block_leagueoflegends"
+    BLOCK_MASTODON = "block_mastodon"
     BLOCK_MESSENGER = "block_messenger"
     BLOCK_MINECRAFT = "block_minecraft"
     BLOCK_NETFLIX = "block_netflix"
     BLOCK_PINTEREST = "block_pinterest"
+    BLOCK_PLAYSTATION_NETWORK = "block_playstation_network"
     BLOCK_PRIMEVIDEO = "block_primevideo"
     BLOCK_REDDIT = "block_reddit"
     BLOCK_ROBLOX = "block_roblox"
@@ -382,19 +379,23 @@ class ParentalControlCategories(StrEnum):
 
     DATING = "dating"
     GAMBLING = "gambling"
+    ONLINE_GAMING = "gaming"
     PIRACY = "piracy"
     PORN = "porn"
     SOCIAL_NETWORKS = "social-networks"
+    VIDEO_STREAMING = "video-streaming"
 
 
 class ParentalControlCategoriesAttrs(StrEnum):
     """Categories type attributes for parental control."""
 
-    BLOCK_DATING = "block_dating"
-    BLOCK_GAMBLING = "block_gambling"
-    BLOCK_PIRACY = "block_piracy"
-    BLOCK_PORN = "block_porn"
+    BLOCK_VIDEO_STREAMING = "block_video_streaming"
     BLOCK_SOCIAL_NETWORKS = "block_social_networks"
+    BLOCK_PORN = "block_porn"
+    BLOCK_PIRACY = "block_piracy"
+    BLOCK_ONLINE_GAMING = "block_online_gaming"
+    BLOCK_GAMBLING = "block_gambling"
+    BLOCK_DATING = "block_dating"
 
 
 class ApiNames(StrEnum):
